==> haskell-regex-tdfa-1.3.2.5-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-tdfa
version:              1.3.2.5
visibility:           public
id:                   regex-tdfa-1.3.2.5-71D7aDzS2d23Ft8PQEnlRo
key:                  regex-tdfa-1.3.2.5-71D7aDzS2d23Ft8PQEnlRo
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2009, Christopher Kuklewicz
maintainer:           Andreas Abel
author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:
    Pure Haskell Tagged DFA Backend for "Text.Regex" (regex-base)

description:
    This package provides a pure Haskell \"Tagged\" DFA regex engine for <//hackage.haskell.org/package/regex-base regex-base>. This implementation was inspired by the algorithm (and Master'\''s thesis) behind the regular expression library known as <https://github.com/laurikari/tre/ TRE or libtre>.

    Please consult the "Text.Regex.TDFA" module for API documentation including a tutorial with usage examples;
    see also <https://wiki.haskell.org/Regular_expressions> for general information about regular expression support in Haskell.

category:             Text
abi:                  7d49f8c491b8e52a5ab63682417f3e28
exposed:              True
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.NewDFA.Tester Text.Regex.TDFA.NewDFA.Uncons
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA Text.Regex.TDFA.Text
    Text.Regex.TDFA.Text.Lazy

hidden-modules:       Paths_regex_tdfa
import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-tdfa-1.3.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-tdfa-1.3.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-tdfa-1.3.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-tdfa
hs-libraries:         HSregex-tdfa-1.3.2.5-71D7aDzS2d23Ft8PQEnlRo
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    mtl-2.2.2 parsec-3.1.16.1
    regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html:         /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-tdfa-1.3.2.5-9.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-tdfa
version:              1.3.2.5
visibility:           public
id:                   regex-tdfa-1.3.2.5-Epq9AbwCUJF5ybNEnhsg9i
key:                  regex-tdfa-1.3.2.5-Epq9AbwCUJF5ybNEnhsg9i
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2009, Christopher Kuklewicz
maintainer:           Andreas Abel
author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:
    Pure Haskell Tagged DFA Backend for "Text.Regex" (regex-base)

description:
    This package provides a pure Haskell \"Tagged\" DFA regex engine for <//hackage.haskell.org/package/regex-base regex-base>. This implementation was inspired by the algorithm (and Master'\''s thesis) behind the regular expression library known as <https://github.com/laurikari/tre/ TRE or libtre>.

    Please consult the "Text.Regex.TDFA" module for API documentation including a tutorial with usage examples;
    see also <https://wiki.haskell.org/Regular_expressions> for general information about regular expression support in Haskell.

category:             Text
abi:                  ef90ef3f842c535934d357122e429975
exposed:              True
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.NewDFA.Tester Text.Regex.TDFA.NewDFA.Uncons
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA Text.Regex.TDFA.Text
    Text.Regex.TDFA.Text.Lazy

hidden-modules:       Paths_regex_tdfa
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/regex-tdfa-1.3.2.5
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/regex-tdfa-1.3.2.5
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/regex-tdfa-1.3.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-tdfa
hs-libraries:         HSregex-tdfa-1.3.2.5-Epq9AbwCUJF5ybNEnhsg9i
depends:
    array-0.5.8.0 base-4.18.3.0 bytestring-0.11.5.4 containers-0.6.7
    mtl-2.3.1 parsec-3.1.16.1
    regex-base-0.94.0.3-2nKwTtnMBcoCMKi4tw1MOe text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html:         /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
